==> lasso_2.1.1.orig.tar.gz: lasso-2.1.1/lasso/xml/id-wsf-2.0/ps_remove_collection_request.c <==
/* $Id: ps_remove_collection_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 * 
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ps_remove_collection_request.h"

/*
 * Schema fragment (liberty-idwsf-people-service-v1.0.xsd):
 *
 * <xs:complexType name="RemoveCollectionRequestType">
 *   <xs:complexContent>
 *     <xs:extension base="RequestAbstractType">
 *       <xs:sequence>
 *         <xs:element ref="TargetObjectID" maxOccurs="unbounded"/>
 *       </xs:sequence>
 *     </xs:extension>
 *   </xs:complexContent>
 * </xs:complexType>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "TargetObjectID", SNIPPET_LIST_NODES,
		G_STRUCT_OFFSET(LassoIdWsf2PsRemoveCollectionRequest, TargetObjectID) },
	{NULL, 0, 0}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static void
instance_init(LassoIdWsf2PsRemoveCollectionRequest *node)
{
	node->TargetObjectID = NULL;
}

static void
class_init(LassoIdWsf2PsRemoveCollectionRequestClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "RemoveCollectionRequest");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_PS_HREF, LASSO_IDWSF2_PS_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_ps_remove_collection_request_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2PsRemoveCollectionRequestClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2PsRemoveCollectionRequest),
			0,
			(GInstanceInitFunc) instance_init,
		};

		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_PS_REQUEST_ABSTRACT,
				"LassoIdWsf2PsRemoveCollectionRequest", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_ps_remove_collection_request_new:
 *
 * Creates a new #LassoIdWsf2PsRemoveCollectionRequest object.
 *
 * Return value: a newly created #LassoIdWsf2PsRemoveCollectionRequest object
 **/
LassoIdWsf2PsRemoveCollectionRequest*
lasso_idwsf2_ps_remove_collection_request_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_PS_REMOVE_COLLECTION_REQUEST, NULL);
}

==> lasso_2.2.1.orig.tar.gz: lasso-2.2.1/lasso/xml/id-wsf-2.0/ps_remove_collection_request.c <==
/* $Id: ps_remove_collection_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 * 
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ps_remove_collection_request.h"

/**
 * SECTION:ps_remove_collection_request
 * @short_description: &lt;ps:RemoveCollectionRequest&gt;
 *
 * <figure><title>Schema fragment for ps:RemoveCollectionRequest</title>
 * <programlisting><![CDATA[
 *
 * <xs:complexType name="RemoveCollectionRequestType">
 *   <xs:complexContent>
 *     <xs:extension base="RequestAbstractType">
 *       <xs:sequence>
 *         <xs:element ref="TargetObjectID" maxOccurs="unbounded"/>
 *       </xs:sequence>
 *     </xs:extension>
 *   </xs:complexContent>
 * </xs:complexType>
 * ]]></programlisting>
 * </figure>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "TargetObjectID", SNIPPET_LIST_NODES,
		G_STRUCT_OFFSET(LassoIdWsf2PsRemoveCollectionRequest, TargetObjectID) },
	{NULL, 0, 0}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static void
instance_init(LassoIdWsf2PsRemoveCollectionRequest *node)
{
	node->TargetObjectID = NULL;
}

static void
class_init(LassoIdWsf2PsRemoveCollectionRequestClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "RemoveCollectionRequest");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_PS_HREF, LASSO_IDWSF2_PS_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_ps_remove_collection_request_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2PsRemoveCollectionRequestClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2PsRemoveCollectionRequest),
			0,
			(GInstanceInitFunc) instance_init,
		};

		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_PS_REQUEST_ABSTRACT,
				"LassoIdWsf2PsRemoveCollectionRequest", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_ps_remove_collection_request_new:
 *
 * Creates a new #LassoIdWsf2PsRemoveCollectionRequest object.
 *
 * Return value: a newly created #LassoIdWsf2PsRemoveCollectionRequest object
 **/
LassoIdWsf2PsRemoveCollectionRequest*
lasso_idwsf2_ps_remove_collection_request_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_PS_REMOVE_COLLECTION_REQUEST, NULL);
}
